@@ -400,17 +400,22 @@ and auxiliary coordinate roles for different data variables.
         # Set HDF chunking
         org_chunks = f.HDF_chunks(HDF_chunks)
         default_chunks = f.HDF_chunks()
-        chunks = org_chunks.copy()
-        shape = f.shape
-        for i, size in org_chunks.iteritems():
-            if size is None:
-                size = default_chunks[i]
-            dim_size = shape[i]
-            if size is None or size > dim_size:
-                size = dim_size
-            chunks[i] = size
-        #--- End: for
-        f.HDF_chunks(chunks)
+        if default_chunks.values() == [None] * f.ndim:
+            f.HDF_chunks(None)
+        else:
+            chunks = org_chunks.copy()
+            shape = f.shape
+            for i, size in org_chunks.iteritems():
+                if size is None:
+                    size = default_chunks[i]
+                dim_size = shape[i]
+                if size is None or size > dim_size:
+                    size = dim_size
+                chunks[i] = size
+
+            f.HDF_chunks(chunks)
+        #--- End: if
+
 
         # Write the field
         _write_a_field(f, g=g)
@@ -742,7 +747,7 @@ written to the file.
     axis_map = {}
     for axis0, axis1 in zip(data._axes, ncdimensions):
         axis_map[axis0] = axis1
-#    print axis_map, data._axes
+
     data._change_axis_names(axis_map)
     data._move_flip_to_partitions()
 
@@ -1580,9 +1585,6 @@ it is not re-written.
 >>> _write_domain_ancillary(f, 'cct2', anc, g=g)
 
 '''
-#    print f.items(key)
-#   print 'axis_to_ncdim=',axis_to_ncdim
-#   print 'f.item_axes('+key+')=', f.item_axes(key)
     ncdimensions = tuple([axis_to_ncdim[axis] for axis in f.item_axes(key)])
 
     create = not _seen(anc, ncdimensions, g=g)
@@ -1930,6 +1932,10 @@ created. The ``seen`` dictionary is updated for *cfvar*.
         if chunksizes == [None] * cfvar.ndim:
             chunksizes = None
 
+        if _debug:
+            print 'chunksizes =', chunksizes
+#        print 'chunksizes =', cfvar, chunksizes
+            
         try:
             g['nc'][ncvar] = g['netcdf'].createVariable(
                 ncvar,
@@ -1943,16 +1949,17 @@ created. The ``seen`` dictionary is updated for *cfvar*.
 #        except (TypeError, RuntimeError):
         except RuntimeError as error:
             error = str(error)
+                
             if error == 'NetCDF: Not a valid data type or _FillValue type mismatch':
                 raise ValueError(
 "Can't write {} data from {!r} to a {} file. Consider using a netCDF4 format or use the 'single' or 'datatype' parameters or change the datatype before writing.".format(
     cfvar.dtype.name, cfvar, g['netcdf'].file_format))
             
-            message = "Can't create variable in {} file from {} ({})".format(g['netcdf'].file_format, cfvar, error)
+            message = "Can't create variable in {} file from {!r}\n{}".format(g['netcdf'].file_format, cfvar, error)
 
             if error == 'NetCDF: NC_UNLIMITED in the wrong index':            
                 raise NetCDFError(
-message+". Unlimited dimension must be the first (leftmost) dimension of the variable. Consider using a netCDF4 format.")
+message+"\nUnlimited dimension must be the first (leftmost) dimension of the variable. Consider using a netCDF4 format instead.")
                 
             raise NetCDFError(message)
         #--- End: try
@@ -2422,6 +2429,7 @@ def _unlimited(f, axis, g=None):
             if f.axis(u, key=True) == axis:
                 unlimited = True
                 break
+    #--- End: if
     
     return unlimited
 #--- End: def
